{ config, pkgs, ... }:

{
  imports =
    [
      /etc/nixos/hardware-configuration.nix
      ./common-headless.nix
      # ./sway.nix
      ./i3.nix
      ./large-sw.nix
      ./uefi.nix
      ./fstrim.nix
      # ./qemu-user.nix
      ./atmega.nix
      ./v4l2loopback.nix
      ./huion.nix
      ./rtl8761b.nix
      ./unstable-nix.nix
      ./nm-restart.nix
    ];

  environment.etc."lvm/lvm.conf".text = ''
    devices {
      issue_discards = 1
    }
  '';
  boot.initrd.luks.devices = {
    sda2_crypt = {
      device = "/dev/disk/by-uuid/2e2e2824-e357-4a75-bddc-8cf386cd0f53";
      preLVM = true;
      allowDiscards = true;
    };
  };

  networking.hostName = "archachatina"; # Define your hostname.
  networking.hostId = "cc7ea3ba";

  hardware.cpu.intel.updateMicrocode = true;

  networking.interfaces."enp3s0".wakeOnLan.enable = true;

  # services.xserver.displayManager.defaultSession = pkgs.lib.mkForce "sway";
  #
  # users.extraUsers.presentation = {
  #   isNormalUser = true;
  #   extraGroups = [ "networkmanager" "audio" ];
  #   # shell = "${pkgs.zsh}/bin/zsh";
  #   shell = "/run/current-system/sw/bin/fish";
  #
  #   password = if config.virtualisation != null then "" else null;
  # };

  environment.systemPackages = with pkgs; [
    beets

    piper
  ];

  services.thermald.enable = true;

  virtualisation.virtualbox.host = {
    enable = true;
    # enableExtensionPack = true;
  };
  # nixpkgs.config.allowUnfree = true;

  virtualisation.libvirtd = {
    enable = true;
  };
  networking.firewall.checkReversePath = false;
  fileSystems."/var/lib/libvirt/images/vaccaria" = {
    device = "//vaccaria.htdf.gebner.org/export/tmp/vms";
    fsType = "cifs";
    options = [ "noauto" "x-systemd.automount" "credentials=/etc/smbcredentials/vaccaria"
      "forceuid" "forcegid" "uid=0" "gid=0" ];
  };

  hardware.opengl.extraPackages = with pkgs; [
    rocm-opencl-icd
    # rocm-runtime-ext
  ];

  services.nix-serve = {
    enable = true;
    secretKeyFile = "/etc/nix-serve/secret.key";
  };
  networking.firewall.allowedTCPPorts = [ config.services.nix-serve.port ];

  services.openssh.forwardX11 = true;

  # nixpkgs.config.packageOverrides = super: let self = super.pkgs; in {
  #     mesa_drivers = self.mesaDarwinOr (
  #       let mo = self.mesa_noglu.override {
  #             llvmPackages = pkgs.llvmPackages_39;
  #             grsecEnabled = false;
  #             enableTextureFloats = true;
  #           };
  #       in mo.drivers
  #     );
  # };

  #boot.kernelPackages = pkgs.lib.mkOverride 10 pkgs.linuxPackages_latest;
  # boot.kernelPackages = pkgs.lib.mkOverride 10 pkgs.linuxPackages;
  # boot.kernelPackages = pkgs.lib.mkOverride 10 pkgs.linuxPackages_5_8;

  services.xserver = {
    videoDrivers = [ "amdgpu" ];
    deviceSection = ''
      Option "TearFree" "on"
    '';
  };

  services.postgresql = {
    enable = true;
    extraPlugins = [ pkgs.postgis ];
  };

  services.ratbagd.enable = true;

  # virtualisation.anbox = {
  #   enable = true;
  # };

  system.stateVersion = "18.03";

}
